@@ -650,10 +650,13 @@ def safe_print(text, end=None, color=Fore.RESET, style=Style.RESET_ALL): # pragm
     - color - the colorama color to use when printing
     - style - the style to use when printing
     """
+    old_stderr = sys.stderr
+    sys.stderr = sys.__stderr__
     if not AWSUME_OPTIONS.get('colors') or os.name == 'nt':
         print(text, file=sys.stderr, end=end)
     else:
         print(style + color + text + Style.RESET_ALL, file=sys.stderr, end=end)
+    sys.stderr = old_stderr
 
 def read_mfa():
     """Read mfa from the command line.
@@ -1500,13 +1503,13 @@ class AwsumeApp(object):
         ----------
         - plugin_manager - the main plugin manager
         """
-        self.load_options(AWSUME_OPTIONS_FILE)
         for directory in [AWS_DIRECTORY, AWSUME_PLUGIN_DIRECTORY]:
             if not os.path.exists(directory):
                 os.makedirs(directory)
         for filename in [AWS_CREDENTIALS_FILE, AWS_CONFIG_FILE]:
             if not os.path.isfile(filename):
                 open(filename, 'a').close()
+        self.load_options(AWSUME_OPTIONS_FILE)
         self.plugin_manager = plugin_manager
         for function_type in self.validFunctions:
             self.awsumeFunctions[function_type] = []
